package
Version:
v1.9.0
Opens a new window with list of versions in this module.
Published: Jun 25, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Stack[T any] struct {
}
NewStack - creates a new empty stack
GetLength - returns the size of the stack
Pop - pops an element from the stack
func (s *Stack[T]) Push(item T)
Push - pushes an element to the stack
Source Files
¶
Click to show internal directories.
Click to hide internal directories.